@@ -1,27 +1,30 @@
+#added SRMR and RMSEA  1/11/25
 "cortest" <- 
 function(R1,R2=NULL, n1=NULL,n2=NULL,fisher=TRUE,cor=TRUE, method = "pearson",use="pairwise") {
 cl <- match.call()
 
-if ((dim(R1)[1] != dim(R1)[2])  & cor) {n1 <- dim(R1)[1] 
+if ((NROW(R1)!= NCOL(R1))  & cor) {n1 <- NROW(R1)
                             # message("R1 was not square, finding R from data")
                              R1 <- cor(R1,use=use,method=method)}
  
 if(!is.matrix(R1) ) R1 <- as.matrix(R1)  #converts data.frames to matrices if needed
 
-p <- dim(R1)[2]
+p <- NCOL(R1)
 if(is.null(n1)) {n1 <- 100 
                 warning("n not specified, 100 used") }
 if(is.null(R2)) { if(fisher) {R <- 0.5*log((1+R1)/(1-R1))
                               R2 <- R*R} else {R2 <- R1*R1}
-                 if(cor) {diag(R2) <- 0
+                 if(cor) {diag(R2)  <- 0
                  E <- (sum(R2*lower.tri(R2)))
-                 z <- sum(R*lower.tri(R))  
-                 df <- p*(p-1)/2} else {
+                 z <- sum(R2*lower.tri(R2))  
+                 df <- p*(p-1)/2
+                 } else {
                      E <- sum(R2)
-                     z <- sum(R1) 
+                     z <- sum(R1^2) 
                      df <- ncol(R1) * nrow(R1)}
                   chisq <- E *(n1-3)
-                 z <- z /sqrt(n1-3)
+                  n <- n1
+                 z <- z/df
                  
                  p.val <- pchisq(chisq,df,lower.tail=FALSE)
     } else {         #end of 1 matrix test
@@ -39,23 +42,28 @@ if(is.null(R2)) { if(fisher) {R <- 0.5*log((1+R1)/(1-R1))
         R <-  R1 - R2   #direct difference 
         R2 <- R*R
         if(is.null(n2)) n2 <- n1
-        n <- (n1*n2)/(n1+n2)  #1/2 harmonic sample size 
+        n <- 2*(n1*n2)/(n1+n2)  # harmonic sample size 
         if(cor) { E <- (sum(R2*lower.tri(R2)))  #just count the lower diagonal elements
                  chisq <- E *(n-3)
                  df <- p*(p-1)/2
-                 z <- sum(R2*lower.tri(R2)) / sqrt(n-3)} else {E <- sum(R2)
+                 z <- sum(R2*lower.tri(R2)) / df} else {E <- sum(R2)
                    chisq <- E * (n-3)
                    df <- ncol(R2) * nrow(R2)
-                   z <- sum(R2) / sqrt(n-3)}
+                   z <- sum(R2) / df
+                   }
                  p.val <- pchisq(chisq,df,lower.tail=FALSE)
       }
-    if (is.null(n2) ) z <- NULL
-   result <- list(chi2=chisq,prob=p.val,df=df,z=z,Call=cl)
+   # if (is.null(n2) ) z <- NULL
+   
+    SRMR <- sqrt(z)
+    RMSEA <- sqrt(max(chisq/(df* n) - 1/(n-1), 0))        #this is x2/(df*N ) -  1/(N-1)   #fixed 4/5/19
+   result <- list(chi2=chisq,prob=p.val,df=df,z,RMSEA=RMSEA,SRMR=SRMR,z =z,Call=cl)
    class(result) <- c("psych","cortest")
    return(result)
     }
 
 
+#SMR amd RMSEA added January 10, 2024
 #version of June 25, 2008
 #revised October 12, 2011 to allow non-square matrices
 
