@@ -1,4 +1,4 @@
-"print.psych.omega" <- 
+"print_psych.omega" <- 
 function(x,digits=2,all=FALSE,cut=NULL,sort=FALSE,...) { 
 xx <- x
 if(!is.null(x$ci)) {
@@ -40,8 +40,9 @@ if(is.null(cut)) cut <- .2
             p2 <- loads[,"p2"]
          	mp2 <- mean(p2)
          	vp2 <- var(p2)
+         	com <- loads[,"com"]
          	p2 <- round(p2,digits)
-	    	print(cbind(fx[,1:(nfactor+sort)],h2,u2,p2),quote="FALSE")
+	    	print(cbind(fx[,1:(nfactor+sort)],h2,u2,p2,com),quote="FALSE")
 	    	
 	   
        numfactors <- dim(x$schmid$sl)[2] -3
@@ -64,7 +65,7 @@ if(is.null(cut)) cut <- .2
     }
     if(!is.null(x$schmid$rms)) {cat("\nThe root mean square of the residuals is ", round(x$schmid$rms,digits),"\n") }
      if(!is.null(x$schmid$crms)) {cat("The df corrected root mean square of the residuals is ", round(x$schmid$crms,digits)) }
-     if(!is.null(x$schmid$RMSEA)) {cat("\nRMSEA index = ",round(x$schmid$RMSEA[1],digits+1), " and the", (1- x$schmid$RMSEA[4])*100,"% confidence intervals are ",round(x$schmid$RMSEA[2:3],digits+1))  }
+     if(!is.null(x$schmid$RMSEA)) {cat("\nRMSEA index = ",round(x$schmid$RMSEA[1],digits+1), " and the", (x$schmid$RMSEA[4])*100,"% confidence intervals are ",round(x$schmid$RMSEA[2:3],digits+1))  }
    	if(!is.null(x$schmid$BIC)) {cat("\nBIC = ",round(x$schmid$BIC,digits))}
    	
    	cat("\n\nCompare this with the adequacy of just a general factor and no group factors")
@@ -73,7 +74,7 @@ if(is.null(cut)) cut <- .2
     }
     if(!is.null(x$gstats$rms)) {cat("\nThe root mean square of the residuals is ", round(x$gstats$rms,digits),"\n") }
      if(!is.null(x$gstats$crms)) {cat("The df corrected root mean square of the residuals is ", round(x$gstats$crms,digits),"\n") }
-     if(!is.null(x$gstats$RMSEA)) {cat("\nRMSEA index = ",round(x$gstats$RMSEA[1],digits+1), " and the", (1- x$gstats$RMSEA[4])*100,"% confidence intervals are ",round(x$gstats$RMSEA[2:3],digits+1))  }
+     if(!is.null(x$gstats$RMSEA)) {cat("\nRMSEA index = ",round(x$gstats$RMSEA[1],digits+1), " and the", (x$gstats$RMSEA[4])*100,"% confidence intervals are ",round(x$gstats$RMSEA[2:3],digits+1))  }
    	if(!is.null(x$gstats$BIC)) {cat("\nBIC = ",round(x$gstats$BIC,digits),"\n")}
    	
    
@@ -112,14 +113,14 @@ if(is.null(cut)) cut <- .2
    
    
    
-   "print.psych.omegaSem" <- 
+   "print_psych.omegaSem" <- 
    function(x,digits=2,all=FALSE,cut=NULL,sort=FALSE,...) { 
      if(is.null(cut)) cut <- .2
 	 cat( x$title,"\n") 
 	 if(!is.null(x$Call)) {# we have run this from omegaSem so we should print omega results first
 	 cat("Call: ")
      print(x$Call)
-   print.psych.omega(x$omegaSem,digits=digits,all=all,cut=cut,sort=sort,...)
+   print_psych.omega(x$omegaSem,digits=digits,all=all,cut=cut,sort=sort,...)
    x <- x$omega.efa
    } 
    loads <- x$cfa.loads
